pyxmpp.all

Package pyxmpp :: Module all |
[hide private]

# Module all

source code

Convenience module containing most important objects from pyxmpp package.

Suggested usage:: import pyxmpp.all

(imports all important names into pyxmpp namespace)

Variables | [hide private]
| __revision__ = ``'``$Id: __init__.py 477 2004-12-29 13:25:42Z jajc``...``
| __package__ = ``'``pyxmpp``'``
| name = ``'``tls_available``'``

Imports: pyxmpp, Stream, StreamError, FatalStreamError, StreamParseError, StreamEncryptionRequired, tls_available, TLSSettings, ClientStream, ClientStreamError, Client, ClientError, Iq, Presence, Message, JID, JIDError, Roster, RosterItem, BadRequestProtocolError, ComponentStreamError, Error, FatalClientError, FatalClientStreamError, FatalComponentStreamError, FeatureNotImplementedProtocolError, HostMismatch, JIDMalformedProtocolError, LegacyAuthenticationError, ProtocolError, RegistrationError, SASLAuthenticationFailed, SASLMechanismNotAvailable, SASLNotAvailable, StreamAuthenticationError, StringprepError, TLSError, TLSNegotiatedButNotAvailableError, TLSNegotiationFailed, logging

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: __init__.py 477 2004-12-29 13:25:42Z jajcus $'